# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OssStockTaskArgs', 'OssStockTask']

@pulumi.input_type
class OssStockTaskArgs:
    def __init__(__self__, *,
                 audio_antispam_freeze_config: Optional[pulumi.Input[str]] = None,
                 audio_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 audio_max_size: Optional[pulumi.Input[int]] = None,
                 audio_opened: Optional[pulumi.Input[bool]] = None,
                 audio_scan_limit: Optional[pulumi.Input[int]] = None,
                 audio_scenes: Optional[pulumi.Input[str]] = None,
                 auto_freeze_type: Optional[pulumi.Input[str]] = None,
                 biz_type: Optional[pulumi.Input[str]] = None,
                 buckets: Optional[pulumi.Input[str]] = None,
                 callback_id: Optional[pulumi.Input[int]] = None,
                 end_date: Optional[pulumi.Input[str]] = None,
                 image_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 image_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_opened: Optional[pulumi.Input[bool]] = None,
                 image_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_scan_limit: Optional[pulumi.Input[int]] = None,
                 image_scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 image_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 scan_image_no_file_type: Optional[pulumi.Input[bool]] = None,
                 start_date: Optional[pulumi.Input[str]] = None,
                 video_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 video_frame_interval: Optional[pulumi.Input[int]] = None,
                 video_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_max_frames: Optional[pulumi.Input[int]] = None,
                 video_max_size: Optional[pulumi.Input[int]] = None,
                 video_opened: Optional[pulumi.Input[bool]] = None,
                 video_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_scan_limit: Optional[pulumi.Input[int]] = None,
                 video_scenes: Optional[pulumi.Input[str]] = None,
                 video_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_voice_antispam_freeze_config: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a OssStockTask resource.
        :param pulumi.Input[str] audio_antispam_freeze_config: Voice auto freeze configuration. Example:{"type":"suggestion","value":"block,review"}. The results are frozen according to the suggestion in the speech detection results.
        :param pulumi.Input[bool] audio_auto_freeze_opened: Audio detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] audio_max_size: Resource property field representing the maximum size of a single audio. 1~2048MB, the default is 200MB, more than not detected.
        :param pulumi.Input[bool] audio_opened: oss stock scan task detect audio. true: scan audio, false: do not scan audio
        :param pulumi.Input[int] audio_scan_limit: The upper limit of voice scan in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] audio_scenes: The audio detection scenarios included in the oss stock scan task. Set the value to antispam.
        :param pulumi.Input[str] auto_freeze_type: Automatic freeze type. Value: acl: modify permissions, copy: Move files
        :param pulumi.Input[str] biz_type: Business scenarios used by the oss stock scan task
        :param pulumi.Input[str] buckets: The bucket configuration list of the oss stock scan task. Example:[{"Bucket":"bucket_01","Selected":true,"Prefixes":["img/test_"],"Type":"exclude"}]
        :param pulumi.Input[int] callback_id: The ID of the primary key of the notification message bound to the oss stock scan task.
        :param pulumi.Input[str] end_date: The end time of the file upload time range indicates the scanning of files uploaded before this time point.
        :param pulumi.Input[str] image_ad_freeze_config: Picture automatically freezes the configuration of ad scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_auto_freeze_opened: Picture detection auto freeze switch. Value: true: auto freeze, false: not auto freeze.
        :param pulumi.Input[str] image_live_freeze_config: Picture automatic freezing live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_opened: oss stock scan task detect images. true: scan images, false: do not scan images
        :param pulumi.Input[str] image_porn_freeze_config: Picture automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[int] image_scan_limit: The upper limit for scanning images in the oss stock scan task. The default value is 10000 images per Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] image_scenes: The image moderation scenario included in the oss stock scan task.Valid values: porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection
        :param pulumi.Input[str] image_terrorism_freeze_config: The picture automatically freezes the configuration of terrorism scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] scan_image_no_file_type: Whether the oss stock scan task detects images with file names without suffixes. true: Detect pictures with file names without suffixes, false: Do not detect pictures with file names without suffixes
        :param pulumi.Input[str] start_date: The start time of the file upload time range represents the files uploaded after scanning this time point.
        :param pulumi.Input[str] video_ad_freeze_config: The video automatically freezes the configuration of ad scenarios. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[bool] video_auto_freeze_opened: Video detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] video_frame_interval: Resource attribute field representing the framing frequency. 1~60 seconds/frame, the default is 1 second/frame
        :param pulumi.Input[str] video_live_freeze_config: Video automatic freeze live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[int] video_max_frames: A resource attribute field that represents the upper limit of a single video frame cut. 5 to 20000 frames, the default is 200 frames
        :param pulumi.Input[int] video_max_size: Resource property field representing the maximum size of a single video. 1~2048MB, the default is 500MB, more than not detected.
        :param pulumi.Input[bool] video_opened: oss stock scan task detect video. true: scan video, false: do not scan video
        :param pulumi.Input[str] video_porn_freeze_config: Video automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the video detection result.
        :param pulumi.Input[int] video_scan_limit: The upper limit of video scanning in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] video_scenes: The video detection scenarios included in the oss stock scan task. porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection antispam: Video voice antispam
        :param pulumi.Input[str] video_terrorism_freeze_config: The video automatically freezes the configuration of terrorism scenes. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[str] video_voice_antispam_freeze_config: Voice auto freeze configuration in video. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        if audio_antispam_freeze_config is not None:
            pulumi.set(__self__, "audio_antispam_freeze_config", audio_antispam_freeze_config)
        if audio_auto_freeze_opened is not None:
            pulumi.set(__self__, "audio_auto_freeze_opened", audio_auto_freeze_opened)
        if audio_max_size is not None:
            pulumi.set(__self__, "audio_max_size", audio_max_size)
        if audio_opened is not None:
            pulumi.set(__self__, "audio_opened", audio_opened)
        if audio_scan_limit is not None:
            pulumi.set(__self__, "audio_scan_limit", audio_scan_limit)
        if audio_scenes is not None:
            pulumi.set(__self__, "audio_scenes", audio_scenes)
        if auto_freeze_type is not None:
            pulumi.set(__self__, "auto_freeze_type", auto_freeze_type)
        if biz_type is not None:
            pulumi.set(__self__, "biz_type", biz_type)
        if buckets is not None:
            pulumi.set(__self__, "buckets", buckets)
        if callback_id is not None:
            pulumi.set(__self__, "callback_id", callback_id)
        if end_date is not None:
            pulumi.set(__self__, "end_date", end_date)
        if image_ad_freeze_config is not None:
            pulumi.set(__self__, "image_ad_freeze_config", image_ad_freeze_config)
        if image_auto_freeze_opened is not None:
            pulumi.set(__self__, "image_auto_freeze_opened", image_auto_freeze_opened)
        if image_live_freeze_config is not None:
            pulumi.set(__self__, "image_live_freeze_config", image_live_freeze_config)
        if image_opened is not None:
            pulumi.set(__self__, "image_opened", image_opened)
        if image_porn_freeze_config is not None:
            pulumi.set(__self__, "image_porn_freeze_config", image_porn_freeze_config)
        if image_scan_limit is not None:
            pulumi.set(__self__, "image_scan_limit", image_scan_limit)
        if image_scenes is not None:
            pulumi.set(__self__, "image_scenes", image_scenes)
        if image_terrorism_freeze_config is not None:
            pulumi.set(__self__, "image_terrorism_freeze_config", image_terrorism_freeze_config)
        if scan_image_no_file_type is not None:
            pulumi.set(__self__, "scan_image_no_file_type", scan_image_no_file_type)
        if start_date is not None:
            pulumi.set(__self__, "start_date", start_date)
        if video_ad_freeze_config is not None:
            pulumi.set(__self__, "video_ad_freeze_config", video_ad_freeze_config)
        if video_auto_freeze_opened is not None:
            pulumi.set(__self__, "video_auto_freeze_opened", video_auto_freeze_opened)
        if video_frame_interval is not None:
            pulumi.set(__self__, "video_frame_interval", video_frame_interval)
        if video_live_freeze_config is not None:
            pulumi.set(__self__, "video_live_freeze_config", video_live_freeze_config)
        if video_max_frames is not None:
            pulumi.set(__self__, "video_max_frames", video_max_frames)
        if video_max_size is not None:
            pulumi.set(__self__, "video_max_size", video_max_size)
        if video_opened is not None:
            pulumi.set(__self__, "video_opened", video_opened)
        if video_porn_freeze_config is not None:
            pulumi.set(__self__, "video_porn_freeze_config", video_porn_freeze_config)
        if video_scan_limit is not None:
            pulumi.set(__self__, "video_scan_limit", video_scan_limit)
        if video_scenes is not None:
            pulumi.set(__self__, "video_scenes", video_scenes)
        if video_terrorism_freeze_config is not None:
            pulumi.set(__self__, "video_terrorism_freeze_config", video_terrorism_freeze_config)
        if video_voice_antispam_freeze_config is not None:
            pulumi.set(__self__, "video_voice_antispam_freeze_config", video_voice_antispam_freeze_config)

    @property
    @pulumi.getter(name="audioAntispamFreezeConfig")
    def audio_antispam_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Voice auto freeze configuration. Example:{"type":"suggestion","value":"block,review"}. The results are frozen according to the suggestion in the speech detection results.
        """
        return pulumi.get(self, "audio_antispam_freeze_config")

    @audio_antispam_freeze_config.setter
    def audio_antispam_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "audio_antispam_freeze_config", value)

    @property
    @pulumi.getter(name="audioAutoFreezeOpened")
    def audio_auto_freeze_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        Audio detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        """
        return pulumi.get(self, "audio_auto_freeze_opened")

    @audio_auto_freeze_opened.setter
    def audio_auto_freeze_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "audio_auto_freeze_opened", value)

    @property
    @pulumi.getter(name="audioMaxSize")
    def audio_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Resource property field representing the maximum size of a single audio. 1~2048MB, the default is 200MB, more than not detected.
        """
        return pulumi.get(self, "audio_max_size")

    @audio_max_size.setter
    def audio_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "audio_max_size", value)

    @property
    @pulumi.getter(name="audioOpened")
    def audio_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        oss stock scan task detect audio. true: scan audio, false: do not scan audio
        """
        return pulumi.get(self, "audio_opened")

    @audio_opened.setter
    def audio_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "audio_opened", value)

    @property
    @pulumi.getter(name="audioScanLimit")
    def audio_scan_limit(self) -> Optional[pulumi.Input[int]]:
        """
        The upper limit of voice scan in the oss stock scan task. The default value is 1000/Bucket.
        """
        return pulumi.get(self, "audio_scan_limit")

    @audio_scan_limit.setter
    def audio_scan_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "audio_scan_limit", value)

    @property
    @pulumi.getter(name="audioScenes")
    def audio_scenes(self) -> Optional[pulumi.Input[str]]:
        """
        The audio detection scenarios included in the oss stock scan task. Set the value to antispam.
        """
        return pulumi.get(self, "audio_scenes")

    @audio_scenes.setter
    def audio_scenes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "audio_scenes", value)

    @property
    @pulumi.getter(name="autoFreezeType")
    def auto_freeze_type(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic freeze type. Value: acl: modify permissions, copy: Move files
        """
        return pulumi.get(self, "auto_freeze_type")

    @auto_freeze_type.setter
    def auto_freeze_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_freeze_type", value)

    @property
    @pulumi.getter(name="bizType")
    def biz_type(self) -> Optional[pulumi.Input[str]]:
        """
        Business scenarios used by the oss stock scan task
        """
        return pulumi.get(self, "biz_type")

    @biz_type.setter
    def biz_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_type", value)

    @property
    @pulumi.getter
    def buckets(self) -> Optional[pulumi.Input[str]]:
        """
        The bucket configuration list of the oss stock scan task. Example:[{"Bucket":"bucket_01","Selected":true,"Prefixes":["img/test_"],"Type":"exclude"}]
        """
        return pulumi.get(self, "buckets")

    @buckets.setter
    def buckets(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "buckets", value)

    @property
    @pulumi.getter(name="callbackId")
    def callback_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the primary key of the notification message bound to the oss stock scan task.
        """
        return pulumi.get(self, "callback_id")

    @callback_id.setter
    def callback_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "callback_id", value)

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> Optional[pulumi.Input[str]]:
        """
        The end time of the file upload time range indicates the scanning of files uploaded before this time point.
        """
        return pulumi.get(self, "end_date")

    @end_date.setter
    def end_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_date", value)

    @property
    @pulumi.getter(name="imageAdFreezeConfig")
    def image_ad_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Picture automatically freezes the configuration of ad scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_ad_freeze_config")

    @image_ad_freeze_config.setter
    def image_ad_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_ad_freeze_config", value)

    @property
    @pulumi.getter(name="imageAutoFreezeOpened")
    def image_auto_freeze_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        Picture detection auto freeze switch. Value: true: auto freeze, false: not auto freeze.
        """
        return pulumi.get(self, "image_auto_freeze_opened")

    @image_auto_freeze_opened.setter
    def image_auto_freeze_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "image_auto_freeze_opened", value)

    @property
    @pulumi.getter(name="imageLiveFreezeConfig")
    def image_live_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Picture automatic freezing live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_live_freeze_config")

    @image_live_freeze_config.setter
    def image_live_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_live_freeze_config", value)

    @property
    @pulumi.getter(name="imageOpened")
    def image_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        oss stock scan task detect images. true: scan images, false: do not scan images
        """
        return pulumi.get(self, "image_opened")

    @image_opened.setter
    def image_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "image_opened", value)

    @property
    @pulumi.getter(name="imagePornFreezeConfig")
    def image_porn_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Picture automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_porn_freeze_config")

    @image_porn_freeze_config.setter
    def image_porn_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_porn_freeze_config", value)

    @property
    @pulumi.getter(name="imageScanLimit")
    def image_scan_limit(self) -> Optional[pulumi.Input[int]]:
        """
        The upper limit for scanning images in the oss stock scan task. The default value is 10000 images per Bucket.
        """
        return pulumi.get(self, "image_scan_limit")

    @image_scan_limit.setter
    def image_scan_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "image_scan_limit", value)

    @property
    @pulumi.getter(name="imageScenes")
    def image_scenes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The image moderation scenario included in the oss stock scan task.Valid values: porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection
        """
        return pulumi.get(self, "image_scenes")

    @image_scenes.setter
    def image_scenes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "image_scenes", value)

    @property
    @pulumi.getter(name="imageTerrorismFreezeConfig")
    def image_terrorism_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        The picture automatically freezes the configuration of terrorism scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_terrorism_freeze_config")

    @image_terrorism_freeze_config.setter
    def image_terrorism_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_terrorism_freeze_config", value)

    @property
    @pulumi.getter(name="scanImageNoFileType")
    def scan_image_no_file_type(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the oss stock scan task detects images with file names without suffixes. true: Detect pictures with file names without suffixes, false: Do not detect pictures with file names without suffixes
        """
        return pulumi.get(self, "scan_image_no_file_type")

    @scan_image_no_file_type.setter
    def scan_image_no_file_type(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "scan_image_no_file_type", value)

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> Optional[pulumi.Input[str]]:
        """
        The start time of the file upload time range represents the files uploaded after scanning this time point.
        """
        return pulumi.get(self, "start_date")

    @start_date.setter
    def start_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_date", value)

    @property
    @pulumi.getter(name="videoAdFreezeConfig")
    def video_ad_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        The video automatically freezes the configuration of ad scenarios. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_ad_freeze_config")

    @video_ad_freeze_config.setter
    def video_ad_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_ad_freeze_config", value)

    @property
    @pulumi.getter(name="videoAutoFreezeOpened")
    def video_auto_freeze_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        Video detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        """
        return pulumi.get(self, "video_auto_freeze_opened")

    @video_auto_freeze_opened.setter
    def video_auto_freeze_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "video_auto_freeze_opened", value)

    @property
    @pulumi.getter(name="videoFrameInterval")
    def video_frame_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Resource attribute field representing the framing frequency. 1~60 seconds/frame, the default is 1 second/frame
        """
        return pulumi.get(self, "video_frame_interval")

    @video_frame_interval.setter
    def video_frame_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_frame_interval", value)

    @property
    @pulumi.getter(name="videoLiveFreezeConfig")
    def video_live_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Video automatic freeze live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_live_freeze_config")

    @video_live_freeze_config.setter
    def video_live_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_live_freeze_config", value)

    @property
    @pulumi.getter(name="videoMaxFrames")
    def video_max_frames(self) -> Optional[pulumi.Input[int]]:
        """
        A resource attribute field that represents the upper limit of a single video frame cut. 5 to 20000 frames, the default is 200 frames
        """
        return pulumi.get(self, "video_max_frames")

    @video_max_frames.setter
    def video_max_frames(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_max_frames", value)

    @property
    @pulumi.getter(name="videoMaxSize")
    def video_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Resource property field representing the maximum size of a single video. 1~2048MB, the default is 500MB, more than not detected.
        """
        return pulumi.get(self, "video_max_size")

    @video_max_size.setter
    def video_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_max_size", value)

    @property
    @pulumi.getter(name="videoOpened")
    def video_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        oss stock scan task detect video. true: scan video, false: do not scan video
        """
        return pulumi.get(self, "video_opened")

    @video_opened.setter
    def video_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "video_opened", value)

    @property
    @pulumi.getter(name="videoPornFreezeConfig")
    def video_porn_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Video automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the video detection result.
        """
        return pulumi.get(self, "video_porn_freeze_config")

    @video_porn_freeze_config.setter
    def video_porn_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_porn_freeze_config", value)

    @property
    @pulumi.getter(name="videoScanLimit")
    def video_scan_limit(self) -> Optional[pulumi.Input[int]]:
        """
        The upper limit of video scanning in the oss stock scan task. The default value is 1000/Bucket.
        """
        return pulumi.get(self, "video_scan_limit")

    @video_scan_limit.setter
    def video_scan_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_scan_limit", value)

    @property
    @pulumi.getter(name="videoScenes")
    def video_scenes(self) -> Optional[pulumi.Input[str]]:
        """
        The video detection scenarios included in the oss stock scan task. porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection antispam: Video voice antispam
        """
        return pulumi.get(self, "video_scenes")

    @video_scenes.setter
    def video_scenes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_scenes", value)

    @property
    @pulumi.getter(name="videoTerrorismFreezeConfig")
    def video_terrorism_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        The video automatically freezes the configuration of terrorism scenes. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_terrorism_freeze_config")

    @video_terrorism_freeze_config.setter
    def video_terrorism_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_terrorism_freeze_config", value)

    @property
    @pulumi.getter(name="videoVoiceAntispamFreezeConfig")
    def video_voice_antispam_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Voice auto freeze configuration in video. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_voice_antispam_freeze_config")

    @video_voice_antispam_freeze_config.setter
    def video_voice_antispam_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_voice_antispam_freeze_config", value)


@pulumi.input_type
class _OssStockTaskState:
    def __init__(__self__, *,
                 audio_antispam_freeze_config: Optional[pulumi.Input[str]] = None,
                 audio_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 audio_max_size: Optional[pulumi.Input[int]] = None,
                 audio_opened: Optional[pulumi.Input[bool]] = None,
                 audio_scan_limit: Optional[pulumi.Input[int]] = None,
                 audio_scenes: Optional[pulumi.Input[str]] = None,
                 auto_freeze_type: Optional[pulumi.Input[str]] = None,
                 biz_type: Optional[pulumi.Input[str]] = None,
                 buckets: Optional[pulumi.Input[str]] = None,
                 callback_id: Optional[pulumi.Input[int]] = None,
                 end_date: Optional[pulumi.Input[str]] = None,
                 image_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 image_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_opened: Optional[pulumi.Input[bool]] = None,
                 image_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_scan_limit: Optional[pulumi.Input[int]] = None,
                 image_scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 image_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 scan_image_no_file_type: Optional[pulumi.Input[bool]] = None,
                 start_date: Optional[pulumi.Input[str]] = None,
                 video_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 video_frame_interval: Optional[pulumi.Input[int]] = None,
                 video_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_max_frames: Optional[pulumi.Input[int]] = None,
                 video_max_size: Optional[pulumi.Input[int]] = None,
                 video_opened: Optional[pulumi.Input[bool]] = None,
                 video_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_scan_limit: Optional[pulumi.Input[int]] = None,
                 video_scenes: Optional[pulumi.Input[str]] = None,
                 video_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_voice_antispam_freeze_config: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering OssStockTask resources.
        :param pulumi.Input[str] audio_antispam_freeze_config: Voice auto freeze configuration. Example:{"type":"suggestion","value":"block,review"}. The results are frozen according to the suggestion in the speech detection results.
        :param pulumi.Input[bool] audio_auto_freeze_opened: Audio detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] audio_max_size: Resource property field representing the maximum size of a single audio. 1~2048MB, the default is 200MB, more than not detected.
        :param pulumi.Input[bool] audio_opened: oss stock scan task detect audio. true: scan audio, false: do not scan audio
        :param pulumi.Input[int] audio_scan_limit: The upper limit of voice scan in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] audio_scenes: The audio detection scenarios included in the oss stock scan task. Set the value to antispam.
        :param pulumi.Input[str] auto_freeze_type: Automatic freeze type. Value: acl: modify permissions, copy: Move files
        :param pulumi.Input[str] biz_type: Business scenarios used by the oss stock scan task
        :param pulumi.Input[str] buckets: The bucket configuration list of the oss stock scan task. Example:[{"Bucket":"bucket_01","Selected":true,"Prefixes":["img/test_"],"Type":"exclude"}]
        :param pulumi.Input[int] callback_id: The ID of the primary key of the notification message bound to the oss stock scan task.
        :param pulumi.Input[str] end_date: The end time of the file upload time range indicates the scanning of files uploaded before this time point.
        :param pulumi.Input[str] image_ad_freeze_config: Picture automatically freezes the configuration of ad scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_auto_freeze_opened: Picture detection auto freeze switch. Value: true: auto freeze, false: not auto freeze.
        :param pulumi.Input[str] image_live_freeze_config: Picture automatic freezing live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_opened: oss stock scan task detect images. true: scan images, false: do not scan images
        :param pulumi.Input[str] image_porn_freeze_config: Picture automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[int] image_scan_limit: The upper limit for scanning images in the oss stock scan task. The default value is 10000 images per Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] image_scenes: The image moderation scenario included in the oss stock scan task.Valid values: porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection
        :param pulumi.Input[str] image_terrorism_freeze_config: The picture automatically freezes the configuration of terrorism scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] scan_image_no_file_type: Whether the oss stock scan task detects images with file names without suffixes. true: Detect pictures with file names without suffixes, false: Do not detect pictures with file names without suffixes
        :param pulumi.Input[str] start_date: The start time of the file upload time range represents the files uploaded after scanning this time point.
        :param pulumi.Input[str] video_ad_freeze_config: The video automatically freezes the configuration of ad scenarios. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[bool] video_auto_freeze_opened: Video detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] video_frame_interval: Resource attribute field representing the framing frequency. 1~60 seconds/frame, the default is 1 second/frame
        :param pulumi.Input[str] video_live_freeze_config: Video automatic freeze live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[int] video_max_frames: A resource attribute field that represents the upper limit of a single video frame cut. 5 to 20000 frames, the default is 200 frames
        :param pulumi.Input[int] video_max_size: Resource property field representing the maximum size of a single video. 1~2048MB, the default is 500MB, more than not detected.
        :param pulumi.Input[bool] video_opened: oss stock scan task detect video. true: scan video, false: do not scan video
        :param pulumi.Input[str] video_porn_freeze_config: Video automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the video detection result.
        :param pulumi.Input[int] video_scan_limit: The upper limit of video scanning in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] video_scenes: The video detection scenarios included in the oss stock scan task. porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection antispam: Video voice antispam
        :param pulumi.Input[str] video_terrorism_freeze_config: The video automatically freezes the configuration of terrorism scenes. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[str] video_voice_antispam_freeze_config: Voice auto freeze configuration in video. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        if audio_antispam_freeze_config is not None:
            pulumi.set(__self__, "audio_antispam_freeze_config", audio_antispam_freeze_config)
        if audio_auto_freeze_opened is not None:
            pulumi.set(__self__, "audio_auto_freeze_opened", audio_auto_freeze_opened)
        if audio_max_size is not None:
            pulumi.set(__self__, "audio_max_size", audio_max_size)
        if audio_opened is not None:
            pulumi.set(__self__, "audio_opened", audio_opened)
        if audio_scan_limit is not None:
            pulumi.set(__self__, "audio_scan_limit", audio_scan_limit)
        if audio_scenes is not None:
            pulumi.set(__self__, "audio_scenes", audio_scenes)
        if auto_freeze_type is not None:
            pulumi.set(__self__, "auto_freeze_type", auto_freeze_type)
        if biz_type is not None:
            pulumi.set(__self__, "biz_type", biz_type)
        if buckets is not None:
            pulumi.set(__self__, "buckets", buckets)
        if callback_id is not None:
            pulumi.set(__self__, "callback_id", callback_id)
        if end_date is not None:
            pulumi.set(__self__, "end_date", end_date)
        if image_ad_freeze_config is not None:
            pulumi.set(__self__, "image_ad_freeze_config", image_ad_freeze_config)
        if image_auto_freeze_opened is not None:
            pulumi.set(__self__, "image_auto_freeze_opened", image_auto_freeze_opened)
        if image_live_freeze_config is not None:
            pulumi.set(__self__, "image_live_freeze_config", image_live_freeze_config)
        if image_opened is not None:
            pulumi.set(__self__, "image_opened", image_opened)
        if image_porn_freeze_config is not None:
            pulumi.set(__self__, "image_porn_freeze_config", image_porn_freeze_config)
        if image_scan_limit is not None:
            pulumi.set(__self__, "image_scan_limit", image_scan_limit)
        if image_scenes is not None:
            pulumi.set(__self__, "image_scenes", image_scenes)
        if image_terrorism_freeze_config is not None:
            pulumi.set(__self__, "image_terrorism_freeze_config", image_terrorism_freeze_config)
        if scan_image_no_file_type is not None:
            pulumi.set(__self__, "scan_image_no_file_type", scan_image_no_file_type)
        if start_date is not None:
            pulumi.set(__self__, "start_date", start_date)
        if video_ad_freeze_config is not None:
            pulumi.set(__self__, "video_ad_freeze_config", video_ad_freeze_config)
        if video_auto_freeze_opened is not None:
            pulumi.set(__self__, "video_auto_freeze_opened", video_auto_freeze_opened)
        if video_frame_interval is not None:
            pulumi.set(__self__, "video_frame_interval", video_frame_interval)
        if video_live_freeze_config is not None:
            pulumi.set(__self__, "video_live_freeze_config", video_live_freeze_config)
        if video_max_frames is not None:
            pulumi.set(__self__, "video_max_frames", video_max_frames)
        if video_max_size is not None:
            pulumi.set(__self__, "video_max_size", video_max_size)
        if video_opened is not None:
            pulumi.set(__self__, "video_opened", video_opened)
        if video_porn_freeze_config is not None:
            pulumi.set(__self__, "video_porn_freeze_config", video_porn_freeze_config)
        if video_scan_limit is not None:
            pulumi.set(__self__, "video_scan_limit", video_scan_limit)
        if video_scenes is not None:
            pulumi.set(__self__, "video_scenes", video_scenes)
        if video_terrorism_freeze_config is not None:
            pulumi.set(__self__, "video_terrorism_freeze_config", video_terrorism_freeze_config)
        if video_voice_antispam_freeze_config is not None:
            pulumi.set(__self__, "video_voice_antispam_freeze_config", video_voice_antispam_freeze_config)

    @property
    @pulumi.getter(name="audioAntispamFreezeConfig")
    def audio_antispam_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Voice auto freeze configuration. Example:{"type":"suggestion","value":"block,review"}. The results are frozen according to the suggestion in the speech detection results.
        """
        return pulumi.get(self, "audio_antispam_freeze_config")

    @audio_antispam_freeze_config.setter
    def audio_antispam_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "audio_antispam_freeze_config", value)

    @property
    @pulumi.getter(name="audioAutoFreezeOpened")
    def audio_auto_freeze_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        Audio detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        """
        return pulumi.get(self, "audio_auto_freeze_opened")

    @audio_auto_freeze_opened.setter
    def audio_auto_freeze_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "audio_auto_freeze_opened", value)

    @property
    @pulumi.getter(name="audioMaxSize")
    def audio_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Resource property field representing the maximum size of a single audio. 1~2048MB, the default is 200MB, more than not detected.
        """
        return pulumi.get(self, "audio_max_size")

    @audio_max_size.setter
    def audio_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "audio_max_size", value)

    @property
    @pulumi.getter(name="audioOpened")
    def audio_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        oss stock scan task detect audio. true: scan audio, false: do not scan audio
        """
        return pulumi.get(self, "audio_opened")

    @audio_opened.setter
    def audio_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "audio_opened", value)

    @property
    @pulumi.getter(name="audioScanLimit")
    def audio_scan_limit(self) -> Optional[pulumi.Input[int]]:
        """
        The upper limit of voice scan in the oss stock scan task. The default value is 1000/Bucket.
        """
        return pulumi.get(self, "audio_scan_limit")

    @audio_scan_limit.setter
    def audio_scan_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "audio_scan_limit", value)

    @property
    @pulumi.getter(name="audioScenes")
    def audio_scenes(self) -> Optional[pulumi.Input[str]]:
        """
        The audio detection scenarios included in the oss stock scan task. Set the value to antispam.
        """
        return pulumi.get(self, "audio_scenes")

    @audio_scenes.setter
    def audio_scenes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "audio_scenes", value)

    @property
    @pulumi.getter(name="autoFreezeType")
    def auto_freeze_type(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic freeze type. Value: acl: modify permissions, copy: Move files
        """
        return pulumi.get(self, "auto_freeze_type")

    @auto_freeze_type.setter
    def auto_freeze_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_freeze_type", value)

    @property
    @pulumi.getter(name="bizType")
    def biz_type(self) -> Optional[pulumi.Input[str]]:
        """
        Business scenarios used by the oss stock scan task
        """
        return pulumi.get(self, "biz_type")

    @biz_type.setter
    def biz_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "biz_type", value)

    @property
    @pulumi.getter
    def buckets(self) -> Optional[pulumi.Input[str]]:
        """
        The bucket configuration list of the oss stock scan task. Example:[{"Bucket":"bucket_01","Selected":true,"Prefixes":["img/test_"],"Type":"exclude"}]
        """
        return pulumi.get(self, "buckets")

    @buckets.setter
    def buckets(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "buckets", value)

    @property
    @pulumi.getter(name="callbackId")
    def callback_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the primary key of the notification message bound to the oss stock scan task.
        """
        return pulumi.get(self, "callback_id")

    @callback_id.setter
    def callback_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "callback_id", value)

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> Optional[pulumi.Input[str]]:
        """
        The end time of the file upload time range indicates the scanning of files uploaded before this time point.
        """
        return pulumi.get(self, "end_date")

    @end_date.setter
    def end_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_date", value)

    @property
    @pulumi.getter(name="imageAdFreezeConfig")
    def image_ad_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Picture automatically freezes the configuration of ad scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_ad_freeze_config")

    @image_ad_freeze_config.setter
    def image_ad_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_ad_freeze_config", value)

    @property
    @pulumi.getter(name="imageAutoFreezeOpened")
    def image_auto_freeze_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        Picture detection auto freeze switch. Value: true: auto freeze, false: not auto freeze.
        """
        return pulumi.get(self, "image_auto_freeze_opened")

    @image_auto_freeze_opened.setter
    def image_auto_freeze_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "image_auto_freeze_opened", value)

    @property
    @pulumi.getter(name="imageLiveFreezeConfig")
    def image_live_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Picture automatic freezing live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_live_freeze_config")

    @image_live_freeze_config.setter
    def image_live_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_live_freeze_config", value)

    @property
    @pulumi.getter(name="imageOpened")
    def image_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        oss stock scan task detect images. true: scan images, false: do not scan images
        """
        return pulumi.get(self, "image_opened")

    @image_opened.setter
    def image_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "image_opened", value)

    @property
    @pulumi.getter(name="imagePornFreezeConfig")
    def image_porn_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Picture automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_porn_freeze_config")

    @image_porn_freeze_config.setter
    def image_porn_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_porn_freeze_config", value)

    @property
    @pulumi.getter(name="imageScanLimit")
    def image_scan_limit(self) -> Optional[pulumi.Input[int]]:
        """
        The upper limit for scanning images in the oss stock scan task. The default value is 10000 images per Bucket.
        """
        return pulumi.get(self, "image_scan_limit")

    @image_scan_limit.setter
    def image_scan_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "image_scan_limit", value)

    @property
    @pulumi.getter(name="imageScenes")
    def image_scenes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The image moderation scenario included in the oss stock scan task.Valid values: porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection
        """
        return pulumi.get(self, "image_scenes")

    @image_scenes.setter
    def image_scenes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "image_scenes", value)

    @property
    @pulumi.getter(name="imageTerrorismFreezeConfig")
    def image_terrorism_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        The picture automatically freezes the configuration of terrorism scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_terrorism_freeze_config")

    @image_terrorism_freeze_config.setter
    def image_terrorism_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "image_terrorism_freeze_config", value)

    @property
    @pulumi.getter(name="scanImageNoFileType")
    def scan_image_no_file_type(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the oss stock scan task detects images with file names without suffixes. true: Detect pictures with file names without suffixes, false: Do not detect pictures with file names without suffixes
        """
        return pulumi.get(self, "scan_image_no_file_type")

    @scan_image_no_file_type.setter
    def scan_image_no_file_type(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "scan_image_no_file_type", value)

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> Optional[pulumi.Input[str]]:
        """
        The start time of the file upload time range represents the files uploaded after scanning this time point.
        """
        return pulumi.get(self, "start_date")

    @start_date.setter
    def start_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "start_date", value)

    @property
    @pulumi.getter(name="videoAdFreezeConfig")
    def video_ad_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        The video automatically freezes the configuration of ad scenarios. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_ad_freeze_config")

    @video_ad_freeze_config.setter
    def video_ad_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_ad_freeze_config", value)

    @property
    @pulumi.getter(name="videoAutoFreezeOpened")
    def video_auto_freeze_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        Video detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        """
        return pulumi.get(self, "video_auto_freeze_opened")

    @video_auto_freeze_opened.setter
    def video_auto_freeze_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "video_auto_freeze_opened", value)

    @property
    @pulumi.getter(name="videoFrameInterval")
    def video_frame_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Resource attribute field representing the framing frequency. 1~60 seconds/frame, the default is 1 second/frame
        """
        return pulumi.get(self, "video_frame_interval")

    @video_frame_interval.setter
    def video_frame_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_frame_interval", value)

    @property
    @pulumi.getter(name="videoLiveFreezeConfig")
    def video_live_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Video automatic freeze live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_live_freeze_config")

    @video_live_freeze_config.setter
    def video_live_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_live_freeze_config", value)

    @property
    @pulumi.getter(name="videoMaxFrames")
    def video_max_frames(self) -> Optional[pulumi.Input[int]]:
        """
        A resource attribute field that represents the upper limit of a single video frame cut. 5 to 20000 frames, the default is 200 frames
        """
        return pulumi.get(self, "video_max_frames")

    @video_max_frames.setter
    def video_max_frames(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_max_frames", value)

    @property
    @pulumi.getter(name="videoMaxSize")
    def video_max_size(self) -> Optional[pulumi.Input[int]]:
        """
        Resource property field representing the maximum size of a single video. 1~2048MB, the default is 500MB, more than not detected.
        """
        return pulumi.get(self, "video_max_size")

    @video_max_size.setter
    def video_max_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_max_size", value)

    @property
    @pulumi.getter(name="videoOpened")
    def video_opened(self) -> Optional[pulumi.Input[bool]]:
        """
        oss stock scan task detect video. true: scan video, false: do not scan video
        """
        return pulumi.get(self, "video_opened")

    @video_opened.setter
    def video_opened(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "video_opened", value)

    @property
    @pulumi.getter(name="videoPornFreezeConfig")
    def video_porn_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Video automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the video detection result.
        """
        return pulumi.get(self, "video_porn_freeze_config")

    @video_porn_freeze_config.setter
    def video_porn_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_porn_freeze_config", value)

    @property
    @pulumi.getter(name="videoScanLimit")
    def video_scan_limit(self) -> Optional[pulumi.Input[int]]:
        """
        The upper limit of video scanning in the oss stock scan task. The default value is 1000/Bucket.
        """
        return pulumi.get(self, "video_scan_limit")

    @video_scan_limit.setter
    def video_scan_limit(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "video_scan_limit", value)

    @property
    @pulumi.getter(name="videoScenes")
    def video_scenes(self) -> Optional[pulumi.Input[str]]:
        """
        The video detection scenarios included in the oss stock scan task. porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection antispam: Video voice antispam
        """
        return pulumi.get(self, "video_scenes")

    @video_scenes.setter
    def video_scenes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_scenes", value)

    @property
    @pulumi.getter(name="videoTerrorismFreezeConfig")
    def video_terrorism_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        The video automatically freezes the configuration of terrorism scenes. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_terrorism_freeze_config")

    @video_terrorism_freeze_config.setter
    def video_terrorism_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_terrorism_freeze_config", value)

    @property
    @pulumi.getter(name="videoVoiceAntispamFreezeConfig")
    def video_voice_antispam_freeze_config(self) -> Optional[pulumi.Input[str]]:
        """
        Voice auto freeze configuration in video. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_voice_antispam_freeze_config")

    @video_voice_antispam_freeze_config.setter
    def video_voice_antispam_freeze_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "video_voice_antispam_freeze_config", value)


class OssStockTask(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audio_antispam_freeze_config: Optional[pulumi.Input[str]] = None,
                 audio_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 audio_max_size: Optional[pulumi.Input[int]] = None,
                 audio_opened: Optional[pulumi.Input[bool]] = None,
                 audio_scan_limit: Optional[pulumi.Input[int]] = None,
                 audio_scenes: Optional[pulumi.Input[str]] = None,
                 auto_freeze_type: Optional[pulumi.Input[str]] = None,
                 biz_type: Optional[pulumi.Input[str]] = None,
                 buckets: Optional[pulumi.Input[str]] = None,
                 callback_id: Optional[pulumi.Input[int]] = None,
                 end_date: Optional[pulumi.Input[str]] = None,
                 image_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 image_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_opened: Optional[pulumi.Input[bool]] = None,
                 image_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_scan_limit: Optional[pulumi.Input[int]] = None,
                 image_scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 image_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 scan_image_no_file_type: Optional[pulumi.Input[bool]] = None,
                 start_date: Optional[pulumi.Input[str]] = None,
                 video_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 video_frame_interval: Optional[pulumi.Input[int]] = None,
                 video_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_max_frames: Optional[pulumi.Input[int]] = None,
                 video_max_size: Optional[pulumi.Input[int]] = None,
                 video_opened: Optional[pulumi.Input[bool]] = None,
                 video_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_scan_limit: Optional[pulumi.Input[int]] = None,
                 video_scenes: Optional[pulumi.Input[str]] = None,
                 video_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_voice_antispam_freeze_config: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        Aligreen Oss Stock Task can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:aligreen/ossStockTask:OssStockTask example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] audio_antispam_freeze_config: Voice auto freeze configuration. Example:{"type":"suggestion","value":"block,review"}. The results are frozen according to the suggestion in the speech detection results.
        :param pulumi.Input[bool] audio_auto_freeze_opened: Audio detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] audio_max_size: Resource property field representing the maximum size of a single audio. 1~2048MB, the default is 200MB, more than not detected.
        :param pulumi.Input[bool] audio_opened: oss stock scan task detect audio. true: scan audio, false: do not scan audio
        :param pulumi.Input[int] audio_scan_limit: The upper limit of voice scan in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] audio_scenes: The audio detection scenarios included in the oss stock scan task. Set the value to antispam.
        :param pulumi.Input[str] auto_freeze_type: Automatic freeze type. Value: acl: modify permissions, copy: Move files
        :param pulumi.Input[str] biz_type: Business scenarios used by the oss stock scan task
        :param pulumi.Input[str] buckets: The bucket configuration list of the oss stock scan task. Example:[{"Bucket":"bucket_01","Selected":true,"Prefixes":["img/test_"],"Type":"exclude"}]
        :param pulumi.Input[int] callback_id: The ID of the primary key of the notification message bound to the oss stock scan task.
        :param pulumi.Input[str] end_date: The end time of the file upload time range indicates the scanning of files uploaded before this time point.
        :param pulumi.Input[str] image_ad_freeze_config: Picture automatically freezes the configuration of ad scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_auto_freeze_opened: Picture detection auto freeze switch. Value: true: auto freeze, false: not auto freeze.
        :param pulumi.Input[str] image_live_freeze_config: Picture automatic freezing live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_opened: oss stock scan task detect images. true: scan images, false: do not scan images
        :param pulumi.Input[str] image_porn_freeze_config: Picture automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[int] image_scan_limit: The upper limit for scanning images in the oss stock scan task. The default value is 10000 images per Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] image_scenes: The image moderation scenario included in the oss stock scan task.Valid values: porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection
        :param pulumi.Input[str] image_terrorism_freeze_config: The picture automatically freezes the configuration of terrorism scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] scan_image_no_file_type: Whether the oss stock scan task detects images with file names without suffixes. true: Detect pictures with file names without suffixes, false: Do not detect pictures with file names without suffixes
        :param pulumi.Input[str] start_date: The start time of the file upload time range represents the files uploaded after scanning this time point.
        :param pulumi.Input[str] video_ad_freeze_config: The video automatically freezes the configuration of ad scenarios. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[bool] video_auto_freeze_opened: Video detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] video_frame_interval: Resource attribute field representing the framing frequency. 1~60 seconds/frame, the default is 1 second/frame
        :param pulumi.Input[str] video_live_freeze_config: Video automatic freeze live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[int] video_max_frames: A resource attribute field that represents the upper limit of a single video frame cut. 5 to 20000 frames, the default is 200 frames
        :param pulumi.Input[int] video_max_size: Resource property field representing the maximum size of a single video. 1~2048MB, the default is 500MB, more than not detected.
        :param pulumi.Input[bool] video_opened: oss stock scan task detect video. true: scan video, false: do not scan video
        :param pulumi.Input[str] video_porn_freeze_config: Video automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the video detection result.
        :param pulumi.Input[int] video_scan_limit: The upper limit of video scanning in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] video_scenes: The video detection scenarios included in the oss stock scan task. porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection antispam: Video voice antispam
        :param pulumi.Input[str] video_terrorism_freeze_config: The video automatically freezes the configuration of terrorism scenes. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[str] video_voice_antispam_freeze_config: Voice auto freeze configuration in video. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[OssStockTaskArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Aligreen Oss Stock Task can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:aligreen/ossStockTask:OssStockTask example <id>
        ```

        :param str resource_name: The name of the resource.
        :param OssStockTaskArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OssStockTaskArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audio_antispam_freeze_config: Optional[pulumi.Input[str]] = None,
                 audio_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 audio_max_size: Optional[pulumi.Input[int]] = None,
                 audio_opened: Optional[pulumi.Input[bool]] = None,
                 audio_scan_limit: Optional[pulumi.Input[int]] = None,
                 audio_scenes: Optional[pulumi.Input[str]] = None,
                 auto_freeze_type: Optional[pulumi.Input[str]] = None,
                 biz_type: Optional[pulumi.Input[str]] = None,
                 buckets: Optional[pulumi.Input[str]] = None,
                 callback_id: Optional[pulumi.Input[int]] = None,
                 end_date: Optional[pulumi.Input[str]] = None,
                 image_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 image_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_opened: Optional[pulumi.Input[bool]] = None,
                 image_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 image_scan_limit: Optional[pulumi.Input[int]] = None,
                 image_scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 image_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 scan_image_no_file_type: Optional[pulumi.Input[bool]] = None,
                 start_date: Optional[pulumi.Input[str]] = None,
                 video_ad_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
                 video_frame_interval: Optional[pulumi.Input[int]] = None,
                 video_live_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_max_frames: Optional[pulumi.Input[int]] = None,
                 video_max_size: Optional[pulumi.Input[int]] = None,
                 video_opened: Optional[pulumi.Input[bool]] = None,
                 video_porn_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_scan_limit: Optional[pulumi.Input[int]] = None,
                 video_scenes: Optional[pulumi.Input[str]] = None,
                 video_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
                 video_voice_antispam_freeze_config: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OssStockTaskArgs.__new__(OssStockTaskArgs)

            __props__.__dict__["audio_antispam_freeze_config"] = audio_antispam_freeze_config
            __props__.__dict__["audio_auto_freeze_opened"] = audio_auto_freeze_opened
            __props__.__dict__["audio_max_size"] = audio_max_size
            __props__.__dict__["audio_opened"] = audio_opened
            __props__.__dict__["audio_scan_limit"] = audio_scan_limit
            __props__.__dict__["audio_scenes"] = audio_scenes
            __props__.__dict__["auto_freeze_type"] = auto_freeze_type
            __props__.__dict__["biz_type"] = biz_type
            __props__.__dict__["buckets"] = buckets
            __props__.__dict__["callback_id"] = callback_id
            __props__.__dict__["end_date"] = end_date
            __props__.__dict__["image_ad_freeze_config"] = image_ad_freeze_config
            __props__.__dict__["image_auto_freeze_opened"] = image_auto_freeze_opened
            __props__.__dict__["image_live_freeze_config"] = image_live_freeze_config
            __props__.__dict__["image_opened"] = image_opened
            __props__.__dict__["image_porn_freeze_config"] = image_porn_freeze_config
            __props__.__dict__["image_scan_limit"] = image_scan_limit
            __props__.__dict__["image_scenes"] = image_scenes
            __props__.__dict__["image_terrorism_freeze_config"] = image_terrorism_freeze_config
            __props__.__dict__["scan_image_no_file_type"] = scan_image_no_file_type
            __props__.__dict__["start_date"] = start_date
            __props__.__dict__["video_ad_freeze_config"] = video_ad_freeze_config
            __props__.__dict__["video_auto_freeze_opened"] = video_auto_freeze_opened
            __props__.__dict__["video_frame_interval"] = video_frame_interval
            __props__.__dict__["video_live_freeze_config"] = video_live_freeze_config
            __props__.__dict__["video_max_frames"] = video_max_frames
            __props__.__dict__["video_max_size"] = video_max_size
            __props__.__dict__["video_opened"] = video_opened
            __props__.__dict__["video_porn_freeze_config"] = video_porn_freeze_config
            __props__.__dict__["video_scan_limit"] = video_scan_limit
            __props__.__dict__["video_scenes"] = video_scenes
            __props__.__dict__["video_terrorism_freeze_config"] = video_terrorism_freeze_config
            __props__.__dict__["video_voice_antispam_freeze_config"] = video_voice_antispam_freeze_config
        super(OssStockTask, __self__).__init__(
            'alicloud:aligreen/ossStockTask:OssStockTask',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            audio_antispam_freeze_config: Optional[pulumi.Input[str]] = None,
            audio_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
            audio_max_size: Optional[pulumi.Input[int]] = None,
            audio_opened: Optional[pulumi.Input[bool]] = None,
            audio_scan_limit: Optional[pulumi.Input[int]] = None,
            audio_scenes: Optional[pulumi.Input[str]] = None,
            auto_freeze_type: Optional[pulumi.Input[str]] = None,
            biz_type: Optional[pulumi.Input[str]] = None,
            buckets: Optional[pulumi.Input[str]] = None,
            callback_id: Optional[pulumi.Input[int]] = None,
            end_date: Optional[pulumi.Input[str]] = None,
            image_ad_freeze_config: Optional[pulumi.Input[str]] = None,
            image_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
            image_live_freeze_config: Optional[pulumi.Input[str]] = None,
            image_opened: Optional[pulumi.Input[bool]] = None,
            image_porn_freeze_config: Optional[pulumi.Input[str]] = None,
            image_scan_limit: Optional[pulumi.Input[int]] = None,
            image_scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            image_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
            scan_image_no_file_type: Optional[pulumi.Input[bool]] = None,
            start_date: Optional[pulumi.Input[str]] = None,
            video_ad_freeze_config: Optional[pulumi.Input[str]] = None,
            video_auto_freeze_opened: Optional[pulumi.Input[bool]] = None,
            video_frame_interval: Optional[pulumi.Input[int]] = None,
            video_live_freeze_config: Optional[pulumi.Input[str]] = None,
            video_max_frames: Optional[pulumi.Input[int]] = None,
            video_max_size: Optional[pulumi.Input[int]] = None,
            video_opened: Optional[pulumi.Input[bool]] = None,
            video_porn_freeze_config: Optional[pulumi.Input[str]] = None,
            video_scan_limit: Optional[pulumi.Input[int]] = None,
            video_scenes: Optional[pulumi.Input[str]] = None,
            video_terrorism_freeze_config: Optional[pulumi.Input[str]] = None,
            video_voice_antispam_freeze_config: Optional[pulumi.Input[str]] = None) -> 'OssStockTask':
        """
        Get an existing OssStockTask resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] audio_antispam_freeze_config: Voice auto freeze configuration. Example:{"type":"suggestion","value":"block,review"}. The results are frozen according to the suggestion in the speech detection results.
        :param pulumi.Input[bool] audio_auto_freeze_opened: Audio detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] audio_max_size: Resource property field representing the maximum size of a single audio. 1~2048MB, the default is 200MB, more than not detected.
        :param pulumi.Input[bool] audio_opened: oss stock scan task detect audio. true: scan audio, false: do not scan audio
        :param pulumi.Input[int] audio_scan_limit: The upper limit of voice scan in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] audio_scenes: The audio detection scenarios included in the oss stock scan task. Set the value to antispam.
        :param pulumi.Input[str] auto_freeze_type: Automatic freeze type. Value: acl: modify permissions, copy: Move files
        :param pulumi.Input[str] biz_type: Business scenarios used by the oss stock scan task
        :param pulumi.Input[str] buckets: The bucket configuration list of the oss stock scan task. Example:[{"Bucket":"bucket_01","Selected":true,"Prefixes":["img/test_"],"Type":"exclude"}]
        :param pulumi.Input[int] callback_id: The ID of the primary key of the notification message bound to the oss stock scan task.
        :param pulumi.Input[str] end_date: The end time of the file upload time range indicates the scanning of files uploaded before this time point.
        :param pulumi.Input[str] image_ad_freeze_config: Picture automatically freezes the configuration of ad scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_auto_freeze_opened: Picture detection auto freeze switch. Value: true: auto freeze, false: not auto freeze.
        :param pulumi.Input[str] image_live_freeze_config: Picture automatic freezing live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] image_opened: oss stock scan task detect images. true: scan images, false: do not scan images
        :param pulumi.Input[str] image_porn_freeze_config: Picture automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[int] image_scan_limit: The upper limit for scanning images in the oss stock scan task. The default value is 10000 images per Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] image_scenes: The image moderation scenario included in the oss stock scan task.Valid values: porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection
        :param pulumi.Input[str] image_terrorism_freeze_config: The picture automatically freezes the configuration of terrorism scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        :param pulumi.Input[bool] scan_image_no_file_type: Whether the oss stock scan task detects images with file names without suffixes. true: Detect pictures with file names without suffixes, false: Do not detect pictures with file names without suffixes
        :param pulumi.Input[str] start_date: The start time of the file upload time range represents the files uploaded after scanning this time point.
        :param pulumi.Input[str] video_ad_freeze_config: The video automatically freezes the configuration of ad scenarios. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[bool] video_auto_freeze_opened: Video detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        :param pulumi.Input[int] video_frame_interval: Resource attribute field representing the framing frequency. 1~60 seconds/frame, the default is 1 second/frame
        :param pulumi.Input[str] video_live_freeze_config: Video automatic freeze live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[int] video_max_frames: A resource attribute field that represents the upper limit of a single video frame cut. 5 to 20000 frames, the default is 200 frames
        :param pulumi.Input[int] video_max_size: Resource property field representing the maximum size of a single video. 1~2048MB, the default is 500MB, more than not detected.
        :param pulumi.Input[bool] video_opened: oss stock scan task detect video. true: scan video, false: do not scan video
        :param pulumi.Input[str] video_porn_freeze_config: Video automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the video detection result.
        :param pulumi.Input[int] video_scan_limit: The upper limit of video scanning in the oss stock scan task. The default value is 1000/Bucket.
        :param pulumi.Input[str] video_scenes: The video detection scenarios included in the oss stock scan task. porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection antispam: Video voice antispam
        :param pulumi.Input[str] video_terrorism_freeze_config: The video automatically freezes the configuration of terrorism scenes. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        :param pulumi.Input[str] video_voice_antispam_freeze_config: Voice auto freeze configuration in video. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OssStockTaskState.__new__(_OssStockTaskState)

        __props__.__dict__["audio_antispam_freeze_config"] = audio_antispam_freeze_config
        __props__.__dict__["audio_auto_freeze_opened"] = audio_auto_freeze_opened
        __props__.__dict__["audio_max_size"] = audio_max_size
        __props__.__dict__["audio_opened"] = audio_opened
        __props__.__dict__["audio_scan_limit"] = audio_scan_limit
        __props__.__dict__["audio_scenes"] = audio_scenes
        __props__.__dict__["auto_freeze_type"] = auto_freeze_type
        __props__.__dict__["biz_type"] = biz_type
        __props__.__dict__["buckets"] = buckets
        __props__.__dict__["callback_id"] = callback_id
        __props__.__dict__["end_date"] = end_date
        __props__.__dict__["image_ad_freeze_config"] = image_ad_freeze_config
        __props__.__dict__["image_auto_freeze_opened"] = image_auto_freeze_opened
        __props__.__dict__["image_live_freeze_config"] = image_live_freeze_config
        __props__.__dict__["image_opened"] = image_opened
        __props__.__dict__["image_porn_freeze_config"] = image_porn_freeze_config
        __props__.__dict__["image_scan_limit"] = image_scan_limit
        __props__.__dict__["image_scenes"] = image_scenes
        __props__.__dict__["image_terrorism_freeze_config"] = image_terrorism_freeze_config
        __props__.__dict__["scan_image_no_file_type"] = scan_image_no_file_type
        __props__.__dict__["start_date"] = start_date
        __props__.__dict__["video_ad_freeze_config"] = video_ad_freeze_config
        __props__.__dict__["video_auto_freeze_opened"] = video_auto_freeze_opened
        __props__.__dict__["video_frame_interval"] = video_frame_interval
        __props__.__dict__["video_live_freeze_config"] = video_live_freeze_config
        __props__.__dict__["video_max_frames"] = video_max_frames
        __props__.__dict__["video_max_size"] = video_max_size
        __props__.__dict__["video_opened"] = video_opened
        __props__.__dict__["video_porn_freeze_config"] = video_porn_freeze_config
        __props__.__dict__["video_scan_limit"] = video_scan_limit
        __props__.__dict__["video_scenes"] = video_scenes
        __props__.__dict__["video_terrorism_freeze_config"] = video_terrorism_freeze_config
        __props__.__dict__["video_voice_antispam_freeze_config"] = video_voice_antispam_freeze_config
        return OssStockTask(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="audioAntispamFreezeConfig")
    def audio_antispam_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        Voice auto freeze configuration. Example:{"type":"suggestion","value":"block,review"}. The results are frozen according to the suggestion in the speech detection results.
        """
        return pulumi.get(self, "audio_antispam_freeze_config")

    @property
    @pulumi.getter(name="audioAutoFreezeOpened")
    def audio_auto_freeze_opened(self) -> pulumi.Output[Optional[bool]]:
        """
        Audio detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        """
        return pulumi.get(self, "audio_auto_freeze_opened")

    @property
    @pulumi.getter(name="audioMaxSize")
    def audio_max_size(self) -> pulumi.Output[Optional[int]]:
        """
        Resource property field representing the maximum size of a single audio. 1~2048MB, the default is 200MB, more than not detected.
        """
        return pulumi.get(self, "audio_max_size")

    @property
    @pulumi.getter(name="audioOpened")
    def audio_opened(self) -> pulumi.Output[Optional[bool]]:
        """
        oss stock scan task detect audio. true: scan audio, false: do not scan audio
        """
        return pulumi.get(self, "audio_opened")

    @property
    @pulumi.getter(name="audioScanLimit")
    def audio_scan_limit(self) -> pulumi.Output[Optional[int]]:
        """
        The upper limit of voice scan in the oss stock scan task. The default value is 1000/Bucket.
        """
        return pulumi.get(self, "audio_scan_limit")

    @property
    @pulumi.getter(name="audioScenes")
    def audio_scenes(self) -> pulumi.Output[Optional[str]]:
        """
        The audio detection scenarios included in the oss stock scan task. Set the value to antispam.
        """
        return pulumi.get(self, "audio_scenes")

    @property
    @pulumi.getter(name="autoFreezeType")
    def auto_freeze_type(self) -> pulumi.Output[Optional[str]]:
        """
        Automatic freeze type. Value: acl: modify permissions, copy: Move files
        """
        return pulumi.get(self, "auto_freeze_type")

    @property
    @pulumi.getter(name="bizType")
    def biz_type(self) -> pulumi.Output[Optional[str]]:
        """
        Business scenarios used by the oss stock scan task
        """
        return pulumi.get(self, "biz_type")

    @property
    @pulumi.getter
    def buckets(self) -> pulumi.Output[Optional[str]]:
        """
        The bucket configuration list of the oss stock scan task. Example:[{"Bucket":"bucket_01","Selected":true,"Prefixes":["img/test_"],"Type":"exclude"}]
        """
        return pulumi.get(self, "buckets")

    @property
    @pulumi.getter(name="callbackId")
    def callback_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the primary key of the notification message bound to the oss stock scan task.
        """
        return pulumi.get(self, "callback_id")

    @property
    @pulumi.getter(name="endDate")
    def end_date(self) -> pulumi.Output[Optional[str]]:
        """
        The end time of the file upload time range indicates the scanning of files uploaded before this time point.
        """
        return pulumi.get(self, "end_date")

    @property
    @pulumi.getter(name="imageAdFreezeConfig")
    def image_ad_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        Picture automatically freezes the configuration of ad scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_ad_freeze_config")

    @property
    @pulumi.getter(name="imageAutoFreezeOpened")
    def image_auto_freeze_opened(self) -> pulumi.Output[Optional[bool]]:
        """
        Picture detection auto freeze switch. Value: true: auto freeze, false: not auto freeze.
        """
        return pulumi.get(self, "image_auto_freeze_opened")

    @property
    @pulumi.getter(name="imageLiveFreezeConfig")
    def image_live_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        Picture automatic freezing live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_live_freeze_config")

    @property
    @pulumi.getter(name="imageOpened")
    def image_opened(self) -> pulumi.Output[Optional[bool]]:
        """
        oss stock scan task detect images. true: scan images, false: do not scan images
        """
        return pulumi.get(self, "image_opened")

    @property
    @pulumi.getter(name="imagePornFreezeConfig")
    def image_porn_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        Picture automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_porn_freeze_config")

    @property
    @pulumi.getter(name="imageScanLimit")
    def image_scan_limit(self) -> pulumi.Output[Optional[int]]:
        """
        The upper limit for scanning images in the oss stock scan task. The default value is 10000 images per Bucket.
        """
        return pulumi.get(self, "image_scan_limit")

    @property
    @pulumi.getter(name="imageScenes")
    def image_scenes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The image moderation scenario included in the oss stock scan task.Valid values: porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection
        """
        return pulumi.get(self, "image_scenes")

    @property
    @pulumi.getter(name="imageTerrorismFreezeConfig")
    def image_terrorism_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        The picture automatically freezes the configuration of terrorism scenes. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the picture detection result.
        """
        return pulumi.get(self, "image_terrorism_freeze_config")

    @property
    @pulumi.getter(name="scanImageNoFileType")
    def scan_image_no_file_type(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the oss stock scan task detects images with file names without suffixes. true: Detect pictures with file names without suffixes, false: Do not detect pictures with file names without suffixes
        """
        return pulumi.get(self, "scan_image_no_file_type")

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> pulumi.Output[Optional[str]]:
        """
        The start time of the file upload time range represents the files uploaded after scanning this time point.
        """
        return pulumi.get(self, "start_date")

    @property
    @pulumi.getter(name="videoAdFreezeConfig")
    def video_ad_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        The video automatically freezes the configuration of ad scenarios. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_ad_freeze_config")

    @property
    @pulumi.getter(name="videoAutoFreezeOpened")
    def video_auto_freeze_opened(self) -> pulumi.Output[Optional[bool]]:
        """
        Video detection auto freeze switch. Value: true: automatically freeze, false: not automatically freeze.
        """
        return pulumi.get(self, "video_auto_freeze_opened")

    @property
    @pulumi.getter(name="videoFrameInterval")
    def video_frame_interval(self) -> pulumi.Output[Optional[int]]:
        """
        Resource attribute field representing the framing frequency. 1~60 seconds/frame, the default is 1 second/frame
        """
        return pulumi.get(self, "video_frame_interval")

    @property
    @pulumi.getter(name="videoLiveFreezeConfig")
    def video_live_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        Video automatic freeze live scene configuration. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_live_freeze_config")

    @property
    @pulumi.getter(name="videoMaxFrames")
    def video_max_frames(self) -> pulumi.Output[Optional[int]]:
        """
        A resource attribute field that represents the upper limit of a single video frame cut. 5 to 20000 frames, the default is 200 frames
        """
        return pulumi.get(self, "video_max_frames")

    @property
    @pulumi.getter(name="videoMaxSize")
    def video_max_size(self) -> pulumi.Output[Optional[int]]:
        """
        Resource property field representing the maximum size of a single video. 1~2048MB, the default is 500MB, more than not detected.
        """
        return pulumi.get(self, "video_max_size")

    @property
    @pulumi.getter(name="videoOpened")
    def video_opened(self) -> pulumi.Output[Optional[bool]]:
        """
        oss stock scan task detect video. true: scan video, false: do not scan video
        """
        return pulumi.get(self, "video_opened")

    @property
    @pulumi.getter(name="videoPornFreezeConfig")
    def video_porn_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        Video automatic freezing porn scene configuration. Example: {"type": "suggestion", "value": "block,review"}. The result will be frozen according to the suggestion in the video detection result.
        """
        return pulumi.get(self, "video_porn_freeze_config")

    @property
    @pulumi.getter(name="videoScanLimit")
    def video_scan_limit(self) -> pulumi.Output[Optional[int]]:
        """
        The upper limit of video scanning in the oss stock scan task. The default value is 1000/Bucket.
        """
        return pulumi.get(self, "video_scan_limit")

    @property
    @pulumi.getter(name="videoScenes")
    def video_scenes(self) -> pulumi.Output[Optional[str]]:
        """
        The video detection scenarios included in the oss stock scan task. porn: pornography detection terrorism: terrorist content detection ad: ad violation detection live: undesirable scene detection antispam: Video voice antispam
        """
        return pulumi.get(self, "video_scenes")

    @property
    @pulumi.getter(name="videoTerrorismFreezeConfig")
    def video_terrorism_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        The video automatically freezes the configuration of terrorism scenes. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_terrorism_freeze_config")

    @property
    @pulumi.getter(name="videoVoiceAntispamFreezeConfig")
    def video_voice_antispam_freeze_config(self) -> pulumi.Output[Optional[str]]:
        """
        Voice auto freeze configuration in video. Example:{"type":"suggestion","value":"block,review"}. The results will be frozen according to the suggestion in the video detection results.
        """
        return pulumi.get(self, "video_voice_antispam_freeze_config")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCollationTimeZonesResult',
    'AwaitableGetCollationTimeZonesResult',
    'get_collation_time_zones',
    'get_collation_time_zones_output',
]

@pulumi.output_type
class GetCollationTimeZonesResult:
    """
    A collection of values returned by getCollationTimeZones.
    """
    def __init__(__self__, collation_time_zones=None, id=None, ids=None, output_file=None):
        if collation_time_zones and not isinstance(collation_time_zones, list):
            raise TypeError("Expected argument 'collation_time_zones' to be a list")
        pulumi.set(__self__, "collation_time_zones", collation_time_zones)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="collationTimeZones")
    def collation_time_zones(self) -> Optional[Sequence['outputs.GetCollationTimeZonesCollationTimeZoneResult']]:
        return pulumi.get(self, "collation_time_zones")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetCollationTimeZonesResult(GetCollationTimeZonesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCollationTimeZonesResult(
            collation_time_zones=self.collation_time_zones,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file)


def get_collation_time_zones(collation_time_zones: Optional[Sequence[Union['GetCollationTimeZonesCollationTimeZoneArgs', 'GetCollationTimeZonesCollationTimeZoneArgsDict']]] = None,
                             output_file: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCollationTimeZonesResult:
    """
    Operation to query the character set collations and time zones available for use in ApsaraDB RDS.

    > **NOTE:** Available in v1.198.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    zones = alicloud.rds.get_collation_time_zones(output_file="./classes.txt")
    pulumi.export("firstRdsCollationTimeZones", zones.collation_time_zones[0])
    ```


    :param Sequence[Union['GetCollationTimeZonesCollationTimeZoneArgs', 'GetCollationTimeZonesCollationTimeZoneArgsDict']] collation_time_zones: An array that consists of the character set collations and time zones that are available for
           use in ApsaraDB RDS.
    :param str output_file: File name where to save data source results (after running `pulumi up`).
    """
    __args__ = dict()
    __args__['collationTimeZones'] = collation_time_zones
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:rds/getCollationTimeZones:getCollationTimeZones', __args__, opts=opts, typ=GetCollationTimeZonesResult).value

    return AwaitableGetCollationTimeZonesResult(
        collation_time_zones=pulumi.get(__ret__, 'collation_time_zones'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_collation_time_zones_output(collation_time_zones: Optional[pulumi.Input[Optional[Sequence[Union['GetCollationTimeZonesCollationTimeZoneArgs', 'GetCollationTimeZonesCollationTimeZoneArgsDict']]]]] = None,
                                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCollationTimeZonesResult]:
    """
    Operation to query the character set collations and time zones available for use in ApsaraDB RDS.

    > **NOTE:** Available in v1.198.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    zones = alicloud.rds.get_collation_time_zones(output_file="./classes.txt")
    pulumi.export("firstRdsCollationTimeZones", zones.collation_time_zones[0])
    ```


    :param Sequence[Union['GetCollationTimeZonesCollationTimeZoneArgs', 'GetCollationTimeZonesCollationTimeZoneArgsDict']] collation_time_zones: An array that consists of the character set collations and time zones that are available for
           use in ApsaraDB RDS.
    :param str output_file: File name where to save data source results (after running `pulumi up`).
    """
    __args__ = dict()
    __args__['collationTimeZones'] = collation_time_zones
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:rds/getCollationTimeZones:getCollationTimeZones', __args__, opts=opts, typ=GetCollationTimeZonesResult)
    return __ret__.apply(lambda __response__: GetCollationTimeZonesResult(
        collation_time_zones=pulumi.get(__response__, 'collation_time_zones'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstanceAllowedIpAttachmentArgs', 'InstanceAllowedIpAttachment']

@pulumi.input_type
class InstanceAllowedIpAttachmentArgs:
    def __init__(__self__, *,
                 allowed_ip: pulumi.Input[str],
                 allowed_type: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 port_range: pulumi.Input[str]):
        """
        The set of arguments for constructing a InstanceAllowedIpAttachment resource.
        :param pulumi.Input[str] allowed_ip: The IP address whitelist. It can be a CIDR block.
        :param pulumi.Input[str] allowed_type: The type of the whitelist. Valid Value: `vpc`, `internet`. **NOTE:** From version 1.179.0, `allowed_type` can be set to `internet`.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port_range: The Port range. Valid Value: `9092/9092`, `9093/9093`, `9094/9094`, `9095/9095`. **NOTE:** From version 1.179.0, `port_range` can be set to `9093/9093`. From version 1.219.0, `port_range` can be set to `9094/9094`, `9095/9095`.
               - `9092/9092`: The port range for access from virtual private clouds (VPCs) by using the default endpoint.
               - `9093/9093`: The port range for access from the Internet.
               - `9094/9094`: The port range for access from VPCs by using the Simple Authentication and Security Layer (SASL) endpoint.
               - `9095/9095`: The port range for access from VPCs by using the Secure Sockets Layer (SSL) endpoint.
        """
        pulumi.set(__self__, "allowed_ip", allowed_ip)
        pulumi.set(__self__, "allowed_type", allowed_type)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "port_range", port_range)

    @property
    @pulumi.getter(name="allowedIp")
    def allowed_ip(self) -> pulumi.Input[str]:
        """
        The IP address whitelist. It can be a CIDR block.
        """
        return pulumi.get(self, "allowed_ip")

    @allowed_ip.setter
    def allowed_ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "allowed_ip", value)

    @property
    @pulumi.getter(name="allowedType")
    def allowed_type(self) -> pulumi.Input[str]:
        """
        The type of the whitelist. Valid Value: `vpc`, `internet`. **NOTE:** From version 1.179.0, `allowed_type` can be set to `internet`.
        """
        return pulumi.get(self, "allowed_type")

    @allowed_type.setter
    def allowed_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "allowed_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="portRange")
    def port_range(self) -> pulumi.Input[str]:
        """
        The Port range. Valid Value: `9092/9092`, `9093/9093`, `9094/9094`, `9095/9095`. **NOTE:** From version 1.179.0, `port_range` can be set to `9093/9093`. From version 1.219.0, `port_range` can be set to `9094/9094`, `9095/9095`.
        - `9092/9092`: The port range for access from virtual private clouds (VPCs) by using the default endpoint.
        - `9093/9093`: The port range for access from the Internet.
        - `9094/9094`: The port range for access from VPCs by using the Simple Authentication and Security Layer (SASL) endpoint.
        - `9095/9095`: The port range for access from VPCs by using the Secure Sockets Layer (SSL) endpoint.
        """
        return pulumi.get(self, "port_range")

    @port_range.setter
    def port_range(self, value: pulumi.Input[str]):
        pulumi.set(self, "port_range", value)


@pulumi.input_type
class _InstanceAllowedIpAttachmentState:
    def __init__(__self__, *,
                 allowed_ip: Optional[pulumi.Input[str]] = None,
                 allowed_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 port_range: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering InstanceAllowedIpAttachment resources.
        :param pulumi.Input[str] allowed_ip: The IP address whitelist. It can be a CIDR block.
        :param pulumi.Input[str] allowed_type: The type of the whitelist. Valid Value: `vpc`, `internet`. **NOTE:** From version 1.179.0, `allowed_type` can be set to `internet`.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port_range: The Port range. Valid Value: `9092/9092`, `9093/9093`, `9094/9094`, `9095/9095`. **NOTE:** From version 1.179.0, `port_range` can be set to `9093/9093`. From version 1.219.0, `port_range` can be set to `9094/9094`, `9095/9095`.
               - `9092/9092`: The port range for access from virtual private clouds (VPCs) by using the default endpoint.
               - `9093/9093`: The port range for access from the Internet.
               - `9094/9094`: The port range for access from VPCs by using the Simple Authentication and Security Layer (SASL) endpoint.
               - `9095/9095`: The port range for access from VPCs by using the Secure Sockets Layer (SSL) endpoint.
        """
        if allowed_ip is not None:
            pulumi.set(__self__, "allowed_ip", allowed_ip)
        if allowed_type is not None:
            pulumi.set(__self__, "allowed_type", allowed_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if port_range is not None:
            pulumi.set(__self__, "port_range", port_range)

    @property
    @pulumi.getter(name="allowedIp")
    def allowed_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address whitelist. It can be a CIDR block.
        """
        return pulumi.get(self, "allowed_ip")

    @allowed_ip.setter
    def allowed_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "allowed_ip", value)

    @property
    @pulumi.getter(name="allowedType")
    def allowed_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the whitelist. Valid Value: `vpc`, `internet`. **NOTE:** From version 1.179.0, `allowed_type` can be set to `internet`.
        """
        return pulumi.get(self, "allowed_type")

    @allowed_type.setter
    def allowed_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "allowed_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="portRange")
    def port_range(self) -> Optional[pulumi.Input[str]]:
        """
        The Port range. Valid Value: `9092/9092`, `9093/9093`, `9094/9094`, `9095/9095`. **NOTE:** From version 1.179.0, `port_range` can be set to `9093/9093`. From version 1.219.0, `port_range` can be set to `9094/9094`, `9095/9095`.
        - `9092/9092`: The port range for access from virtual private clouds (VPCs) by using the default endpoint.
        - `9093/9093`: The port range for access from the Internet.
        - `9094/9094`: The port range for access from VPCs by using the Simple Authentication and Security Layer (SASL) endpoint.
        - `9095/9095`: The port range for access from VPCs by using the Secure Sockets Layer (SSL) endpoint.
        """
        return pulumi.get(self, "port_range")

    @port_range.setter
    def port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_range", value)


class InstanceAllowedIpAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_ip: Optional[pulumi.Input[str]] = None,
                 allowed_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 port_range: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a AliKafka Instance Allowed Ip Attachment resource.

        For information about AliKafka Instance Allowed Ip Attachment and how to use it, see [What is Instance Allowed Ip Attachment](https://www.alibabacloud.com/help/en/message-queue-for-apache-kafka/latest/api-alikafka-2019-09-16-updateallowedip).

        > **NOTE:** Available since v1.163.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default", vpc_id=default_network.id)
        default_instance = alicloud.alikafka.Instance("default",
            name=f"{name}-{default_integer['result']}",
            partition_num=50,
            disk_type=1,
            disk_size=500,
            deploy_type=5,
            io_max=20,
            vswitch_id=default_switch.id,
            security_group=default_security_group.id)
        default_instance_allowed_ip_attachment = alicloud.alikafka.InstanceAllowedIpAttachment("default",
            instance_id=default_instance.id,
            allowed_type="vpc",
            port_range="9092/9092",
            allowed_ip="114.237.9.78/32")
        ```

        ## Import

        AliKafka Instance Allowed Ip Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:alikafka/instanceAllowedIpAttachment:InstanceAllowedIpAttachment example <instance_id>:<allowed_type>:<port_range>:<allowed_ip>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] allowed_ip: The IP address whitelist. It can be a CIDR block.
        :param pulumi.Input[str] allowed_type: The type of the whitelist. Valid Value: `vpc`, `internet`. **NOTE:** From version 1.179.0, `allowed_type` can be set to `internet`.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port_range: The Port range. Valid Value: `9092/9092`, `9093/9093`, `9094/9094`, `9095/9095`. **NOTE:** From version 1.179.0, `port_range` can be set to `9093/9093`. From version 1.219.0, `port_range` can be set to `9094/9094`, `9095/9095`.
               - `9092/9092`: The port range for access from virtual private clouds (VPCs) by using the default endpoint.
               - `9093/9093`: The port range for access from the Internet.
               - `9094/9094`: The port range for access from VPCs by using the Simple Authentication and Security Layer (SASL) endpoint.
               - `9095/9095`: The port range for access from VPCs by using the Secure Sockets Layer (SSL) endpoint.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceAllowedIpAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a AliKafka Instance Allowed Ip Attachment resource.

        For information about AliKafka Instance Allowed Ip Attachment and how to use it, see [What is Instance Allowed Ip Attachment](https://www.alibabacloud.com/help/en/message-queue-for-apache-kafka/latest/api-alikafka-2019-09-16-updateallowedip).

        > **NOTE:** Available since v1.163.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default = alicloud.get_zones(available_resource_creation="VSwitch")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default.zones[0].id)
        default_security_group = alicloud.ecs.SecurityGroup("default", vpc_id=default_network.id)
        default_instance = alicloud.alikafka.Instance("default",
            name=f"{name}-{default_integer['result']}",
            partition_num=50,
            disk_type=1,
            disk_size=500,
            deploy_type=5,
            io_max=20,
            vswitch_id=default_switch.id,
            security_group=default_security_group.id)
        default_instance_allowed_ip_attachment = alicloud.alikafka.InstanceAllowedIpAttachment("default",
            instance_id=default_instance.id,
            allowed_type="vpc",
            port_range="9092/9092",
            allowed_ip="114.237.9.78/32")
        ```

        ## Import

        AliKafka Instance Allowed Ip Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:alikafka/instanceAllowedIpAttachment:InstanceAllowedIpAttachment example <instance_id>:<allowed_type>:<port_range>:<allowed_ip>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceAllowedIpAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceAllowedIpAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_ip: Optional[pulumi.Input[str]] = None,
                 allowed_type: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 port_range: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceAllowedIpAttachmentArgs.__new__(InstanceAllowedIpAttachmentArgs)

            if allowed_ip is None and not opts.urn:
                raise TypeError("Missing required property 'allowed_ip'")
            __props__.__dict__["allowed_ip"] = allowed_ip
            if allowed_type is None and not opts.urn:
                raise TypeError("Missing required property 'allowed_type'")
            __props__.__dict__["allowed_type"] = allowed_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if port_range is None and not opts.urn:
                raise TypeError("Missing required property 'port_range'")
            __props__.__dict__["port_range"] = port_range
        super(InstanceAllowedIpAttachment, __self__).__init__(
            'alicloud:alikafka/instanceAllowedIpAttachment:InstanceAllowedIpAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_ip: Optional[pulumi.Input[str]] = None,
            allowed_type: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            port_range: Optional[pulumi.Input[str]] = None) -> 'InstanceAllowedIpAttachment':
        """
        Get an existing InstanceAllowedIpAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] allowed_ip: The IP address whitelist. It can be a CIDR block.
        :param pulumi.Input[str] allowed_type: The type of the whitelist. Valid Value: `vpc`, `internet`. **NOTE:** From version 1.179.0, `allowed_type` can be set to `internet`.
        :param pulumi.Input[str] instance_id: The ID of the instance.
        :param pulumi.Input[str] port_range: The Port range. Valid Value: `9092/9092`, `9093/9093`, `9094/9094`, `9095/9095`. **NOTE:** From version 1.179.0, `port_range` can be set to `9093/9093`. From version 1.219.0, `port_range` can be set to `9094/9094`, `9095/9095`.
               - `9092/9092`: The port range for access from virtual private clouds (VPCs) by using the default endpoint.
               - `9093/9093`: The port range for access from the Internet.
               - `9094/9094`: The port range for access from VPCs by using the Simple Authentication and Security Layer (SASL) endpoint.
               - `9095/9095`: The port range for access from VPCs by using the Secure Sockets Layer (SSL) endpoint.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceAllowedIpAttachmentState.__new__(_InstanceAllowedIpAttachmentState)

        __props__.__dict__["allowed_ip"] = allowed_ip
        __props__.__dict__["allowed_type"] = allowed_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["port_range"] = port_range
        return InstanceAllowedIpAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedIp")
    def allowed_ip(self) -> pulumi.Output[str]:
        """
        The IP address whitelist. It can be a CIDR block.
        """
        return pulumi.get(self, "allowed_ip")

    @property
    @pulumi.getter(name="allowedType")
    def allowed_type(self) -> pulumi.Output[str]:
        """
        The type of the whitelist. Valid Value: `vpc`, `internet`. **NOTE:** From version 1.179.0, `allowed_type` can be set to `internet`.
        """
        return pulumi.get(self, "allowed_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="portRange")
    def port_range(self) -> pulumi.Output[str]:
        """
        The Port range. Valid Value: `9092/9092`, `9093/9093`, `9094/9094`, `9095/9095`. **NOTE:** From version 1.179.0, `port_range` can be set to `9093/9093`. From version 1.219.0, `port_range` can be set to `9094/9094`, `9095/9095`.
        - `9092/9092`: The port range for access from virtual private clouds (VPCs) by using the default endpoint.
        - `9093/9093`: The port range for access from the Internet.
        - `9094/9094`: The port range for access from VPCs by using the Simple Authentication and Security Layer (SASL) endpoint.
        - `9095/9095`: The port range for access from VPCs by using the Secure Sockets Layer (SSL) endpoint.
        """
        return pulumi.get(self, "port_range")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBandwidthPackagesResult',
    'AwaitableGetBandwidthPackagesResult',
    'get_bandwidth_packages',
    'get_bandwidth_packages_output',
]

@pulumi.output_type
class GetBandwidthPackagesResult:
    """
    A collection of values returned by getBandwidthPackages.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, name_regex=None, names=None, output_file=None, packages=None, status=None, type=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if packages and not isinstance(packages, list):
            raise TypeError("Expected argument 'packages' to be a list")
        pulumi.set(__self__, "packages", packages)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def packages(self) -> Sequence['outputs.GetBandwidthPackagesPackageResult']:
        return pulumi.get(self, "packages")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


class AwaitableGetBandwidthPackagesResult(GetBandwidthPackagesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBandwidthPackagesResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            packages=self.packages,
            status=self.status,
            type=self.type)


def get_bandwidth_packages(enable_details: Optional[bool] = None,
                           ids: Optional[Sequence[str]] = None,
                           name_regex: Optional[str] = None,
                           output_file: Optional[str] = None,
                           status: Optional[str] = None,
                           type: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBandwidthPackagesResult:
    """
    This data source provides the Global Accelerator (GA) Bandwidth Packages of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.112.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.ga.get_bandwidth_packages(ids=["example_value"],
        name_regex="the_resource_name")
    pulumi.export("firstGaBandwidthPackageId", example.packages[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Bandwidth Package IDs.
    :param str name_regex: A regex string to filter results by Bandwidth Package name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the bandwidth plan. Valid values: `active`, `binded`, `binding`, `finacialLocked`, `init`, `unbinding`, `updating`.
    :param str type: The type of the bandwidth plan. Valid values: `Basic`, `CrossDomain`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ga/getBandwidthPackages:getBandwidthPackages', __args__, opts=opts, typ=GetBandwidthPackagesResult).value

    return AwaitableGetBandwidthPackagesResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        packages=pulumi.get(__ret__, 'packages'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_bandwidth_packages_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                                  ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                  name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                  status: Optional[pulumi.Input[Optional[str]]] = None,
                                  type: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBandwidthPackagesResult]:
    """
    This data source provides the Global Accelerator (GA) Bandwidth Packages of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.112.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.ga.get_bandwidth_packages(ids=["example_value"],
        name_regex="the_resource_name")
    pulumi.export("firstGaBandwidthPackageId", example.packages[0].id)
    ```


    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Bandwidth Package IDs.
    :param str name_regex: A regex string to filter results by Bandwidth Package name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the bandwidth plan. Valid values: `active`, `binded`, `binding`, `finacialLocked`, `init`, `unbinding`, `updating`.
    :param str type: The type of the bandwidth plan. Valid values: `Basic`, `CrossDomain`.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ga/getBandwidthPackages:getBandwidthPackages', __args__, opts=opts, typ=GetBandwidthPackagesResult)
    return __ret__.apply(lambda __response__: GetBandwidthPackagesResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        packages=pulumi.get(__response__, 'packages'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))
